package tfg;

import org.jsfml.graphics.Color;
import org.jsfml.graphics.RenderWindow;
import org.jsfml.system.Vector2i;
import org.jsfml.window.VideoMode;
import org.jsfml.window.event.Event;
import org.jsfml.window.event.KeyEvent;


public class Game {
	private RenderWindow window = new RenderWindow();
	private final String windowTitle = "TFG Game";
	private final Vector2i screenResolution = new Vector2i(640, 480);

	private Player player = new Player();

	public static void main(String[] args) {
		Game g = new Game(); /* Create temp object of self. */
		g.run(); /* Invoke run. */
	}

	/**
	 * Run the game.
	 */
	public void run() {
		initialize();

		/* Main loop. */
		while(window.isOpen()) {
			window.clear(Color.BLACK);
			window.draw(player.getSprite());
			window.display();

			/* Event handler. */
			for(Event event : window.pollEvents()) {
				if(event.type == Event.Type.CLOSED) {
					/* User clicked window close. */
					window.close();
				} else if(event.type == Event.Type.KEY_PRESSED) {
					KeyEvent keyEv = event.asKeyEvent();
					switch(keyEv.key) {
						case ESCAPE:
							window.close();
							break;
						case W:
							player.move(Direction.NORTH);
							break;
						case S:
							player.move(Direction.SOUTH);
							break;
						case A:
							player.move(Direction.WEST);
							break;
						case D:
							player.move(Direction.EAST);
					}
				}
			}
		}
	}

	/**
	 * Configure settings once at startup.
	 */
	public void initialize() {
		window.create(new VideoMode(screenResolution.x, screenResolution.y),
			windowTitle);
	}

}